##  Creating a Custom Fact Sheet Type
**Note**
Depending on the configuration of your workspace, you may need to submit a ticket to [SAP LeanIX Support![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support") to create custom fact sheet types. If you’re an SAP customer, submit a request from the [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/") portal.
To create a custom fact sheet type, follow these steps:
  1. In the administration area, navigate to the Meta Model Configuration section.
  2. Click New Fact Sheet Type.
  3. In the Internal Name field, enter a unique key for the fact sheet type, which is also referred to as the technical name. This key is used in APIs, the fact sheet URL, the Excel import/export feature, and more. Once set, the key cannot be changed later.
  4. Enter a name for the fact sheet type in both singular and plural forms in your selected language. Optionally, enter a description. We recommend adding translations to any other languages relevant to workspace users.
  5. Click Create.


A new fact sheet type is created. You land on the fact sheet configuration page where you can configure fact sheet fields, relations, permissions, and more.
**Note**
When you create a custom fact sheet type, it becomes immediately available to all workspace users after you click Create, even if it’s not fully configured yet. Therefore, consider creating new fact sheet types outside of regular business hours to prevent any disruptions or negative experiences for workspace users.
